import React, { useContext } from 'react';
import RedoButton from '../RedoButton/RedoButton';
import { QuestionTypes } from '../CioQuiz/actions';
import QuizContext from '../CioQuiz/context';
import ResultFilters from '../ResultFilters/ResultFilters';
import ZeroResults from '../ZeroResults/ZeroResults';
import Results from '../Results/Results';
export default function ResultContainer(props) {
    const { options, resetQuizSessionId } = props;
    const { addToCartCallback, clickItemCallback, resultCardSalePriceKey, resultCardRegularPriceKey, } = options;
    const { resultsResponse } = useContext(QuizContext);
    const { dispatch } = useContext(QuizContext);
    const filterExpression = resultsResponse?.request?.collection_filter_expression;
    const zeroResults = !resultsResponse?.response?.results?.length;
    const resultsTitle = zeroResults ? 'Oops, there are no results' : 'Here are your results';
    const onResetClick = () => {
        if (dispatch && resultsResponse) {
            resetQuizSessionId();
            dispatch({
                type: QuestionTypes.Reset,
            });
        }
    };
    if (resultsResponse) {
        return (React.createElement("div", { className: 'cio-results-container' },
            React.createElement("h1", { className: 'cio-results-title' }, resultsTitle),
            React.createElement("div", { className: 'cio-results-filter-and-redo-container' },
                React.createElement(ResultFilters, { filters: filterExpression }),
                React.createElement(RedoButton, { onClick: onResetClick })),
            !zeroResults && (React.createElement(Results, { addToCartCallback: addToCartCallback, clickItemCallback: clickItemCallback, resultCardSalePriceKey: resultCardSalePriceKey, resultCardRegularPriceKey: resultCardRegularPriceKey })),
            zeroResults && React.createElement(ZeroResults, null)));
    }
    return React.createElement("div", null, "Loading");
}
